@@ -31,7 +31,7 @@
 #' @details
 #' The procedure runs the exact order based structure discovery approach of Koivisto and Sood (2004) to find the most probable posterior network (DAG). The local.score is the node cache, as created using \code{\link{buildScoreCache}} (or manually provided the same format is used). Note that the scope of this search is given by the options used in local.score, for example, by restricting the number of parents or the ban or retain constraints given there.
 #'
-#' This routine can take a long time to complete and is highly sensitive to the number of nodes in the network. It is recommended to use this on a reduced data set to get an idea as to the computational practicality of this approach.  In particular, memory usage can quickly increase to beyond what may be available. For additive models, problems comprising up to 20 nodes are feasible on most machines. Memory requirements can increase considerably after this, but then so does the run time making this less practical. It is recommended that some form of over-modeling adjustment is performed on this resulting DAG (unless dealing with vast numbers of observations), for example, using parametric bootstrapping, which is straightforward to implement in MCMC engines such as JAGS or WinBUGS. See the case studies at \url{http://r-bayesian-networks.org}
+#' This routine can take a long time to complete and is highly sensitive to the number of nodes in the network. It is recommended to use this on a reduced data set to get an idea as to the computational practicality of this approach.  In particular, memory usage can quickly increase to beyond what may be available. For additive models, problems comprising up to 20 nodes are feasible on most machines. Memory requirements can increase considerably after this, but then so does the run time making this less practical. It is recommended that some form of over-modeling adjustment is performed on this resulting DAG (unless dealing with vast numbers of observations), for example, using parametric bootstrapping, which is straightforward to implement in MCMC engines such as JAGS or WinBUGS. See the case studies at \url{https://r-bayesian-networks.org/}
 #' or the files provided in the package directories \code{inst/bootstrapping_example} and \code{inst/old_vignette}
 #' for details.
 #'
@@ -48,69 +48,83 @@
 #' ##############################
 #' ## Example 1
 #' ##############################
-#'
-#' ## This data comes with `abn` see ?ex1.dag.data
-#' mydat <- ex1.dag.data[1:5000, c(1:7,10)]
+#' ## This data comes with 'abn' see ?ex1.dag.data
+#' mydat <- ex1.dag.data[1:5000, c(1:7, 10)]
 #'
 #' ## Setup distribution list for each node:
-#' mydists <- list(b1="binomial", p1="poisson", g1="gaussian", b2="binomial",
-#'                 p2="poisson", b3="binomial", g2="gaussian", g3="gaussian")
+#' mydists <- list(b1 = "binomial",
+#'                 p1 = "poisson",
+#'                 g1 = "gaussian",
+#'                 b2 = "binomial",
+#'                 p2 = "poisson",
+#'                 b3 = "binomial",
+#'                 g2 = "gaussian",
+#'                 g3 = "gaussian")
 #'
 #' ## Parent limits, for speed purposes quite specific here:
-#' max.par <- list("b1"=0,"p1"=0,"g1"=1,"b2"=1,"p2"=2,"b3"=3,"g2"=3,"g3"=2)
+#' max_par <- list("b1" = 0,
+#'                 "p1" = 0,
+#'                 "g1" = 1,
+#'                 "b2" = 1,
+#'                 "p2" = 2,
+#'                 "b3" = 3,
+#'                 "g2" = 3,
+#'                 "g3" = 2)
 #' ## Now build cache (no constraints in ban nor retain)
-#' mycache <- buildScoreCache(data.df=mydat, data.dists=mydists, max.parents=max.par)
+#' mycache <- buildScoreCache(data.df = mydat,
+#'                            data.dists = mydists,
+#'                            max.parents = max_par)
 #'
 #' ## Find the globally best DAG:
-#' mp.dag <- mostProbable(score.cache=mycache)
-#' myres <- fitAbn(object=mp.dag,create.graph=TRUE)
-#' myres$mlik
+#' mp_dag <- mostProbable(score.cache = mycache)
+#' myres <- fitAbn(object = mp_dag,
+#'                 create.graph = TRUE)
 #' plot(myres) # plot the best model
 #'
-#' ## last line is essentially equivalent to:
-#' # plotAbn(dag=mp.dag$dag, data.dists=mydists, fitted.values=myres$modes)
-#'
 #' ## Fit the known true DAG (up to variables 'b4' and 'b5'):
-#' true.dag <- matrix(data=0, ncol=8, nrow=8)
-#' colnames(true.dag) <- rownames(true.dag) <- names(mydists)
+#' true_dag <- matrix(data = 0, ncol = 8, nrow = 8)
+#' colnames(true_dag) <- rownames(true_dag) <- names(mydists)
 #'
-#' true.dag["p2",c("b1","p1")] <- 1
-#' true.dag["b3",c("b1","g1","b2")] <- 1
-#' true.dag["g2",c("p1","g1","b2")] <- 1
-#' true.dag["g3",c("g1","b2")] <- 1
+#' true_dag["p2", c("b1", "p1")] <- 1
+#' true_dag["b3", c("b1", "g1", "b2")] <- 1
+#' true_dag["g2", c("p1", "g1", "b2")] <- 1
+#' true_dag["g3", c("g1", "b2")] <- 1
 #'
-#' fitAbn(dag=true.dag, data.df=mydat, data.dists=mydists)$mlik
+#' fitAbn(dag = true_dag,
+#'        data.df = mydat,
+#'        data.dists = mydists)$mlik
 #'
 #' #################################################################
 #' ## Example 2 - models with random effects
 #' #################################################################
-#'
 #' ## This data comes with abn see ?ex3.dag.data
-#' mydat <- ex3.dag.data[,c(1:4,14)]
-#' mydists <- list(b1="binomial", b2="binomial", b3="binomial", b4="binomial")
+#' mydat <- ex3.dag.data[, c(1:4, 14)]
+#' mydists <- list(b1 = "binomial",
+#'                 b2 = "binomial",
+#'                 b3 = "binomial",
+#'                 b4 = "binomial")
 #'
 #' ## This takes a few seconds and requires INLA:
-#' mycache.mixed <- buildScoreCache(data.df=mydat,
-#'                                  data.dists=mydists,
-#'                                  group.var="group",
-#'                                  max.parents=2)
+#' mycache_mixed <- buildScoreCache(data.df = mydat,
+#'                                  data.dists = mydists,
+#'                                  group.var = "group",
+#'                                  max.parents = 2)
 #'
 #' ## Find the most probable DAG:
-#' mp.dag <- mostProbable(score.cache=mycache.mixed)
+#' mp_dag <- mostProbable(score.cache = mycache_mixed)
 #' ## and get goodness of fit:
-#' fitAbn(object=mp.dag,
-#'        group.var="group")$mlik
+#' fitAbn(object = mp_dag,
+#'        group.var = "group")$mlik
 #' }
 #' @keywords models
 mostProbable <- function(score.cache, score="bic", prior.choice=1,
                          verbose=TRUE, ...) {
 
-    if (!inherits(score.cache,"abnCache")) {
-        stop("score.cache should be an object of class 'abnCache' ")
-    }
-    score <- c("mlik","aic","bic",
-               "mdl")[pmatch(tolower(score), c("mlik","aic","bic","mdl"))][1]
-    if (is.na(score)) stop("wrong specification of 'score'.")
+  if (!inherits(score.cache,"abnCache")) {
+    stop("score.cache should be an object of class 'abnCache' ")
+  }
+  score <- c("mlik","aic","bic", "mdl")[pmatch(tolower(score), c("mlik","aic","bic","mdl"))][1]
+  if (is.na(score)) stop("wrong specification of 'score'.")
 
   ### FIXME: error here? it seems that the following is only required for method='mle'
   if (score.cache$method=='mle') {
@@ -119,44 +133,43 @@ mostProbable <- function(score.cache, score="bic", prior.choice=1,
     if(score=="mdl"){score.cache$mlik <- (-score.cache$mdl)}
   }
 
-    data.df <- score.cache$data.df[,names(score.cache$data.dists)]; ## n.b. this might be adjusted from original data.df ! when adjusting for random effect
+  data.df <- score.cache$data.df[,names(score.cache$data.dists)]; ## n.b. this might be adjusted from original data.df ! when adjusting for random effect
 
-    loc.numnodes <- as.integer(dim(score.cache$node.defn)[2]);
-    loc.maxparents <- max(apply(score.cache$node.defn,1,sum)); ## maximum number of parents in any node
-    score.cache$children <- as.integer(score.cache$children-1); ## since C indexes from 0
+  loc.numnodes <- as.integer(dim(score.cache$node.defn)[2]);
+  loc.maxparents <- max(apply(score.cache$node.defn,1,sum)); ## maximum number of parents in any node
+  score.cache$children <- as.integer(score.cache$children-1); ## since C indexes from 0
 
-    ## check for missing values - check both NA and NaN - should be just the latter but it may be possible
-    ## I guess for these to switch back and forth between R and C
-    score.cache$mlik <- ifelse(is.nan(score.cache$mlik),-.Machine$double.xmax,score.cache$mlik);## if node calc gave a NaN
-    score.cache$mlik <- ifelse(is.na(score.cache$mlik),-.Machine$double.xmax,score.cache$mlik);## if node calc gave a NA
-#print(score.cache$mlik);
-    if(is.null(data.df)){stop("Must provide data.df - data used in call to mostprobable()");}
+  ## check for missing values - check both NA and NaN - should be just the latter but it may be possible
+  ## I guess for these to switch back and forth between R and C
+  score.cache$mlik <- ifelse(is.nan(score.cache$mlik),-.Machine$double.xmax,score.cache$mlik);## if node calc gave a NaN
+  score.cache$mlik <- ifelse(is.na(score.cache$mlik),-.Machine$double.xmax,score.cache$mlik);## if node calc gave a NA
 
-    ## need the number of combinations per node
-    loc.num.subsets <- as.integer(table(score.cache$children));
-    if(length(loc.num.subsets)!=dim(data.df)[2]){stop("At least one node has no valid parent combinations given constraints applied!");}
-    ##now get indexes where end node starts and stops
-    loc.end <- cumsum(c(table(score.cache$children)));
-    loc.start <- c(1,loc.end[-length(loc.end)]+1);
-    loc.end <- loc.end-1;#C from 0
-    loc.end <- as.integer(loc.end);
-    loc.start <- loc.start-1;#C from 0
-    loc.start <- as.integer(loc.start);
+  if(is.null(data.df)){stop("Must provide data.df - data used in call to mostprobable()");}
 
-    if(prior.choice != 1 && prior.choice != 2){stop("prior choice must be 1 or 2!\n");}
+  ## need the number of combinations per node
+  loc.num.subsets <- as.integer(table(score.cache$children));
+  if(length(loc.num.subsets)!=dim(data.df)[2]){stop("At least one node has no valid parent combinations given constraints applied!");}
+  ##now get indexes where end node starts and stops
+  loc.end <- cumsum(c(table(score.cache$children)));
+  loc.start <- c(1,loc.end[-length(loc.end)]+1);
+  loc.end <- loc.end-1;#C from 0
+  loc.end <- as.integer(loc.end);
+  loc.start <- loc.start-1;#C from 0
+  loc.start <- as.integer(loc.start);
 
-    res.prob <- .Call("mostprobable_C",score.cache,loc.numnodes,loc.start,loc.end, as.integer(prior.choice),verbose
-               ,PACKAGE="abn" ## uncomment to load as package not shlib
-              )
-    loc.res <- matrix(data=res.prob[[1]],ncol=loc.numnodes,byrow=TRUE)
-    colnames(loc.res) <- rownames(loc.res) <- names(data.df)
+  if(prior.choice != 1 && prior.choice != 2){stop("prior choice must be 1 or 2!\n");}
 
-    junk <- gc(FALSE)
-    ## some garbage collection
+  res.prob <- .Call("mostprobable_C",score.cache,loc.numnodes,loc.start,loc.end, as.integer(prior.choice), verbose
+                    ,PACKAGE="abn" ## uncomment to load as package not shlib
+  )
+  loc.res <- matrix(data=res.prob[[1]], ncol=loc.numnodes, byrow=TRUE)
+  colnames(loc.res) <- rownames(loc.res) <- names(data.df)
 
-    out <- list(dag=(loc.res), score.cache=score.cache, score=score)
-    class(out) <- c("abnMostprobable","abnLearned")
-    return(out)
+  junk <- gc(FALSE) ## some garbage collection
+
+  out <- list(dag=(loc.res), score.cache=score.cache, score=score)
+  class(out) <- c("abnMostprobable","abnLearned")
+  return(out)
 
 }
 
