@@ -331,9 +331,11 @@ Rprintf("############ Warning - Priors turned off - use only for checking mlik v
    
    } /** end of error being too large **/
    
-   if(dag->hessianError[nodeid]==DBL_MAX){/** in this case nelder mead could not estimate the hessian error so abort as something is probably
-                                               very wrong here */
-                                          error("");}/** use the R tryCatch rather than the switch for status below **/
+   if(dag->hessianError[nodeid]==DBL_MAX){
+    /** in this case nelder mead could not estimate the hessian error so abort as something is probably very wrong here */
+    error("Hessian error estimation failed.");
+    }
+    /** use the R tryCatch rather than the switch for status below **/
                                           
       /*Rprintf("GVALUE=%e nodeid=%d\n",gvalue,nodeid+1);*/
        /*finitestepsize=1E-04;
@@ -456,7 +458,10 @@ const gsl_vector *priormean = designdata->priormean;
   tau=gsl_vector_get(betaincTau,n_betas);/** extract the tau-precision from *beta - last entry */
   /*Rprintf("g_outer_ tau=%f\n",tau);*/
  
-  if(tau<0.0){Rprintf("tau negative in g_outer!\n");error("");}
+  if(tau<0.0){
+    Rprintf("tau negative in g_outer!\n");
+    error("tau negative in g_outer!\n");
+    }
   
   /** beta are the parameters values at which the function is to be evaluated **/
        /** gvalue is the return value - a single double */
@@ -571,7 +576,10 @@ int rv_hessg_pois_outer( gsl_vector* beta, void* params, gsl_matrix* hessgvalues
   F.function = &g_outer_pois_single;
   F.params = gparams;
   
- if(gsl_vector_get(beta,beta->size-1)<0.0){Rprintf("negative tau in hess %e\n",gsl_vector_get(beta,beta->size-1));error("");}
+ if(gsl_vector_get(beta,beta->size-1)<0.0){
+  Rprintf("negative tau in hess %e\n",gsl_vector_get(beta,beta->size-1));
+  error("negative tau in hess\n");
+  }
  
   /** diagnonal terms d^2f/dx^2 - finite differences - difference between two */
   for(i=0;i<hessgvalues->size1;i++){
